global enter"\\micro.intra\projekt\P0523$\P0523_Gem\DG_Income_Mental_Health\Data"
global masterdir "\\micro.intra\projekt\P0523$\P0523_Gem\DG_Income_Mental_Health"



use "$enter\Family1.dta", clear // Generated in GenInfo do-file
drop if year<2001 | year>2011
drop bdate bmonth

g married = id_spouse != .
bysort id: egen evermarried = max(married)
drop if evermarried == 0 // Drop those who never married
drop evermarried

ren (byear sex) =_own 
drop if yearmar<2001 

drop if id_spouse == . // Drop unmarried
drop married

bysort id: egen minyear = min(year) // Establish those who were married in 2001
keep if minyear == 2001

bysort id: egen minage = min(age_t)
drop if minage>54 // Drop those who are over 63 by the end of observation
drop if minage<18
drop minage

ren id id_own 
ren id_spouse id

merge m:1 id using "$enter\ID_TCC_adj.dta" // Generated in GenInfo do-file
keep if _merge == 3
drop _merge
ren (byear sex) =_spouse
g age_t_spouse = year - byear_spouse
ren sex_own sex

merge m:1 id year using "$enter\INC1.dta" // Generated in Income do-file
drop if _merge == 2
drop _merge
ren (tlont tkassa ttj) =_spouse

ren id id_spouse
ren id_own id

merge m:1 id year using "$enter\INC1.dta" // Generated in Income do-file
drop if _merge == 2
drop _merge
ren (tlont tkassa ttj) =_own

g year_diag = year

duplicates drop id year_diag, force

merge 1:m id year_diag using "$enter\outpat1.dta" // Generated in Diagnoses do-file
drop if _merge == 2

global ment1 mental mood substance neurotic schiz behav adult selfharm psych child ret organic // Diagnostic categories

foreach var in $ment1 {
replace `var' = 0 if _merge == 1
}
drop _merge month

foreach var in $ment1 {
bysort id year_diag: egen `var'_max = max(`var') // Designate those with any MH diagnosis in given year
}

bysort id year_diag: g count_n = _n
drop if count_n>1 // Keep person once in records even with multiple diagnoses
drop mental - organic
drop count_n

* Diagnoses in year t+1

drop year_diag
g year_diag = year+1

duplicates drop id year_diag, force

merge 1:m id year_diag using "$enter\outpat1.dta" // Generated in Diagnoses do-file
drop if _merge == 2

foreach var in $ment1 {
replace `var' = 0 if _merge == 1
}
drop _merge

foreach var in $ment1 {
bysort id year_diag: egen `var'_max1 = max(`var')
}

bysort id year_diag: g count_n = _n // Keep person once in records even with multiple diagnoses
drop if count_n>1
drop mental - organic
drop count_n

foreach var in $ment1 {
g `var'_new = `var'_max
replace `var'_new = `var'_max1 if `var'_max == 0 & `var'_max1 == 1
}

ren mental_max1 mental2
replace mental2 = 100 if mental2 == 1

global ment2 mental_new mood_new substance_new neurotic_new schiz_new behav_new adult_new selfharm_new psych_new child_new ret_new organic_new

foreach var in $ment2 {
replace `var' = 100 if `var' == 1
}

g newshare = ttj_own/(ttj_own+ttj_spouse) // Wife's share in total family income 
replace newshare = ttj_spouse/(ttj_own+ttj_spouse) if sex == 0
replace newshare = 1 if newshare>1 // Cap few outliers with negative income
replace newshare = 0 if newshare<0
replace newshare = . if ttj_own == 0 & ttj_spouse == 0 // Drop those with 0 income
replace newshare = . if ttj_own == . | ttj_spouse == . // Drop those with missing income

drop *max1
drop neurotic_max - year_diag

merge m:m id using "$masterdir\Raw Data\ID_EDUAGG.dta" //Add parental education
drop if _merge == 2
drop _merge
drop degobt_agg sun2000niva_grov_agg sun2000niva_old_agg duplicate source
ren sun2000niva_agg niva
g sun = substr(sun2000inr_agg,1,3)
drop sun2000inr_agg
destring niva, replace // Level of education variable
destring sun, replace // Degree type variable

g highschool = niva > 319 // Designate highest attained levels of education
g voc = niva > 410 & niva < 535 // Vocational degrees
g college = niva > 534  // University degrees
g stem = sun<600 & sun>400 & niva > 535 // STEM degrees

g immigrant = birthcountry != "SVERIGE"

merge m:m id using "$enter\fertility.dta" // Generated in GenInfo do-file
drop if _merge == 2
g haskids = _merge == 3
replace haskids = 0 if yearkid>year // No kids up to date
drop _merge
bysort id year: g count_n = _n
drop if count_n>1 // Remove duplicates stemming from multiple kids
drop count_n

g above = newshare>0.5
g share2 = newshare*newshare
g share3 = share2*newshare
g share4 = share3*newshare
g share5 = share4*newshare

bysort id: egen maxabove = max(above) // Check for crossing threshold at some point
bysort id: egen minabove = min(above)

g annual = ttj_own/1000
g sick = tsjuk>0 // Reception of sick benefits dummy
g faminc = ttj_own + ttj_spouse // Joint family income

g logwage = log(ttj_own+1)
g logspouse = log(ttj_spouse+1)

g roundshare = round(newshare, 0.005)
g unemp = tkassa_own>0 // Reception of unemployment benefits

bysort id: gen nyears = _N
bysort id id_spouse: egen lastyear = max(year) // Designate last year of marriage
g divorce_event = year == lastyear
replace divorce_event = 0 if lastyear == 2011 // Divorce in given year
g divorce_event2 = year == lastyear | year == lastyear-1 // Divorce in subsequent year
replace divorce_event2 = 0 if lastyear == 2011


merge m:1 id using "$enter\hindex.dta"  // Somatic health indicator; generated in the Diagnoses do file
drop if _merge == 2
replace hindex = 0 if _merge == 1 // No somatic diagnoses
drop _merge

g birth = haskids == 1 & year == yearkid // Children in given year

gen bin = .  // Generate the 1000 income share bins for figure A.1
forval i = 0(0.001)0.999 {
	replace bin = `i' if newshare > `i' & newshare < `i' + 0.001
}
egen count = count(newshare), by(bin)



label var age_t "Age"
label var immigrant "Immigrant"
label var college "College Degree"
label var stem "STEM Degree"
label var haskids "Has Children"
label var annual "Annual Earnings"
label var birth "Had Child"
label var sick "Sick Leave"
label var unemp "Unemployed"
label var newshare "Share Wife's Earnings"
label var mental_new "Mental Health Disorder"
label var behav_new "Eating and Sleeping Disorder"
label var child_new "Hyperactivity and Conduct Disorder"
label var mood_new "Depression and Mood Disorder"
label var substance_new "Substance-Related Disorder"
label var neurotic_new "Neurotic and Stress Disorder"
label var psych_new "Learning and Socialisation Disorder"
label var schiz_new "Schizotypal Disorder"
label var adult_new "Adult Personality Disorder"
label var ret_new "Mental Retardation"
label var organic_new "Organic Disorder"

save "$enter\spouse1.dta", replace



/////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////Density///////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////


binscatter count bin, xtitle("Share Wifes Earnings", height (5) size(medlarge)) xlabel(, labsize(medlarge)) ytitle("Frequency", height (5) size(medlarge)) ylabel(0(1000)3000, labsize(medlarge)) graphregion(color(white)) n(1000) rd(0.5) line(none) color(gray)
graph export density.pdf, replace

rddensity newshare, c(0.5) //McCrary tests
rddensity newshare if ttj_own != ttj_spouse, c(0.5)



//////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////Figure 1///////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////


use "$enter\Family1.dta", clear
drop if id_spouse == .

drop mun civilstatus yearmar birthcountry byear bdate bmonth age_t

merge m:1 id year using "$enter\INC1.dta"
keep if _merge == 3
drop _merge tlont tkassa
ren  ttj ttj_own

ren id id_own
ren id_spouse id

merge m:1 id year using "$enter\INC1.dta"
drop if _merge == 2
drop _merge tkassa tlont
ren ttj ttj_spouse

ren id id_spouse 
ren id_own id

keep if sex == 0
g wifemore = ttj_spouse>ttj_own //Generate share wives earning more than husbands

preserve

collapse (mean) wifemore, by(year)

twoway connected wifemore year, ytitle("Probability Wife Earns More", height (5) size(medlarge)) xtitle("Year", height (5) size(medlarge)) ylabel(0.24(0.02)0.34) xlabel(1998(3)2016, labsize(medlarge)) graphregion(color(white)) lcolor(gs6) mcolor(gs6)
graph export wifemore.pdf, replace



use "$enter\spouse1.dta", clear

collapse mental_max, by(year sex)
g ment_pct = mental_max*100

twoway connected ment_pct year if sex == 0, lcolor(gs6) mcolor(gs6) || connected ment_pct year if sex == 1, legend(lab(1 Male) lab(2 Female) pos(11)) xtitle("Year", height (5) size(medlarge)) xlabel(2000(2)2012) ytitle("Mental Health Incidence, %", height (5) size(medlarge)) ylabel(0(1)3) graphregion(color(white)) lcolor(gs10) mcolor(gs10)
graph export mental.pdf, replace

restore




//////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////Figure 2///////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

use "$enter\spouse1.dta", clear


binscatter mental_new logwage if logwage>10, by(sex) xtitle("Log Annual Wages", height (5) size(medlarge)) xlabel(, labsize(medlarge)) legend(lab(1 Male) lab(2 Female)) ytitle("Mental Health Incidence, %", height (5) size(medlarge)) ylabel(0(2)8, labsize(medlarge)) graphregion(color(white)) nquantiles(50) colors(gray gray%30) line(none) name(g1)

binscatter mental_new logspouse if logspouse>10, by(sex) xtitle("Log Spouse Wages", height (5) size(medlarge)) xlabel(, labsize(medlarge)) legend(lab(1 Male) lab(2 Female)) ytitle("" height (5) size(medlarge)) ylabel(0(2)8, labsize(medlarge)) graphregion(color(white)) nquantiles(50) colors(gray gray%30) line(none) name(g2)

grc1leg g1 g2, legendfrom(g1) position(6) graphregion(color(white))
graph export binscatter_log.pdf, replace


/////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////////// Figure 3 ////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////

use "$enter\spouse1.dta", clear


rdplot mental_new newshare if newshare>0.35 &newshare<0.65, c(0.5) nbins(15 15) graph_options(xtitle("Share Wife's Earnings", size(medlarge)) ytitle("Mental Health Incidence, %", size(medlarge)) graphregion(color(white))  xlabel(0.35(0.05)0.65,labsize(medlarge)) ylabel(1.5(1)5.5,labsize(medlarge)) legend(off))
graph export rd3565.pdf, replace

g inc1000 = tlont_own/1000

binscatter inc1000 newshare, by(sex) xtitle("Share Wife's Earnings", height (5) size(medlarge)) xlabel(, labsize(medlarge)) legend(lab(1 Male) lab(2 Female) pos(11)) ytitle("Annual Income, 1000 SEK", height (5) size(medlarge)) ylabel(0(200)600, labsize(medlarge))  xlabel(0(0.25)1, labsize(medlarge))  graphregion(color(white)) colors(gray gray%30) nquantiles(100) rd(0.5) line(none)
graph export sharetotal.pdf, replace




////////////////////////////////////////////////////////////////////////////////////
////////////////////////////// Table 1 /////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////

use "$enter\spouse1.dta", clear


est clear

eststo men: estpost sum age_t immigrant college stem annual unemp birth sick newshare mental_new child_new substance_new mood_new behav_new neurotic_new psych_new schiz_new adult_new organic_new ret_new if sex == 0

eststo women: estpost sum age_t immigrant college stem annual unemp birth sick newshare mental_new child_new substance_new mood_new behav_new neurotic_new psych_new schiz_new adult_new organic_new ret_new if sex == 1


esttab men women using summary.tex, replace ///
	prehead("\textbf{Variable}") ///
	nomtitles label booktabs noobs fragment nonum ///
	refcat(age_t "\addlinespace \textbf{Background Variables} & \multicolumn{3}{c}{\textbf{Men}}& \multicolumn{3}{c}{\textbf{Women}}"  mental_new  "\addlinespace \textbf{Diagnostic Vairables, \%}" , nolabel) ///
	cells("count(fmt(%9.0gc) label(N)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") 
	



///////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////// Table 2 //////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

use "$enter\spouse1.dta", clear


global controls age_t highschool college stem immigrant birth sick divorce_event faminc
drop if ttj_own == ttj_spouse & ttj_own != 0 // Drop identical earners

est clear

sum mental_new
local mental_avg = round(r(mean),0.01) 
 
eststo: reg mental_new above newshare if newshare>0.35 & newshare<0.65, cluster(roundshare)
eststo: reg mental_new above newshare $controls if newshare>0.35 & newshare<0.65, cluster(roundshare)
estadd local controls "X"
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65, absorb(id) cluster(roundshare) keepsingletons
estadd local controls "X"
estadd local id "X"
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65, absorb(id year) cluster(roundshare) keepsingletons
estadd local controls "X"
estadd local id "X"
estadd local year "X"
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons
estadd local controls "X"
estadd local id "X"
estadd local year "X"
estadd local trends "X"


esttab using mental_new.tex, replace ///
		b(2) se nodepvars noomitted nonotes noobs fragment nomtitles booktabs label ///
	prehead("&\multicolumn{5}{c}{\textbf{Mental Health Diagnosis} [0,100]} \\ \cmidrule{2-6}") ///
	posthead ("\midrule \addlinespace") ///
	postfoot ("") ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	keep (above) coeflabels (above "\textbf{All} (`mental_avg'\%)") ///
	stats(controls id year trends N r2,fmt(0 0 0 0 %9.0gc 2)  labels("Controls" "Individual FE" "Year FE" "Individual Trends"  "\midrule Observations" "\emph{R}-squared")) 
	


forval i = 0/1 {

est clear

sum mental_new if sex == `i'
local mental_avg_`i' = round(r(mean),0.01) 

eststo: reg mental_new above newshare if newshare>0.35 & newshare<0.65 & sex == `i', cluster(roundshare)
eststo: reg mental_new above newshare $controls if newshare>0.35 & newshare<0.65 & sex == `i', cluster(roundshare)
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65 & sex == `i', absorb(id) cluster(roundshare) keepsingletons
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65 & sex == `i', absorb(id year) cluster(roundshare) keepsingletons
eststo: reghdfe mental_new above newshare $controls if newshare>0.35 & newshare<0.65 & sex == `i', absorb(id##c.year) cluster(roundshare) keepsingletons

esttab using mental_new.tex, append ///
		b(2) se nonum nodepvars noomitted nonotes noobs fragment nomtitles booktabs label ///
	posthead ("\addlinespace") ///
	postfoot ("") ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	keep (above) coeflabels (above "\textbf{Males} (`mental_avg_`i''\%)") ///
	
}



//////////////////////////////////////////////////////////////////////////
///////////////////////// Table 3 ////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////	

use "$enter\spouse1.dta", clear
drop if ttj_own == ttj_spouse & ttj_own != 0 // Drop identical earners



est clear

eststo: reghdfe substance_new above newshare $controls if newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons
eststo: reghdfe substance_new above newshare $controls if sex == 0 & newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons
eststo: reghdfe substance_new above newshare $controls if sex == 1 & newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons

esttab using breakdown.tex, replace ///
		b(2) se nodepvars noomitted nonotes noobs fragment nomtitles booktabs label ///
	prehead("\textbf{Diagnosis:} &\textbf{All}&\textbf{Males}&\textbf{Females} \\ \cmidrule{2-4}") ///
	posthead ("\midrule \addlinespace") ///
	postfoot ("") ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	keep (above) coeflabels (above "Substance") ///


foreach var in mood_new behav_new neurotic_new schiz_new child_new adult_new {

est clear

eststo: reghdfe `var' above newshare $controls if newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons
eststo: reghdfe `var' above newshare $controls if sex == 0 & newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons
eststo: reghdfe `var' above newshare $controls if sex == 1 & newshare>0.35 & newshare<0.65, absorb(id##c.year) cluster(roundshare) keepsingletons


esttab using breakdown.tex, append ///
		b(2) se nodepvars noomitted nonum nonotes noobs fragment nomtitles booktabs label ///
	prehead("") ///
	posthead ("\addlinespace") ///
	postfoot ("") ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	keep (above) coeflabels (above "`var'") ///

}
